@@ -12,12 +12,20 @@ def create_new_project(session):
     )
 
     if not continue_project_creation:
-        print("ok bye 👋")
+        print("Ok bye 👋")
         quit()
 
     projects = session.query("Project")
     users = session.query("User")
 
+    internal_project_handle = session.query('Project where name is "Team_Intern"').one()
+
+    for c in internal_project_handle["children"]:
+        if c["name"] == "Assets":
+            for a in c["children"]:
+                if a["name"] == "AMS-LOGO":
+                    ams_thumb = a["thumbnail_id"]
+
     clearConsole()
 
     print(f"Ok {session.api_user}, which team are we making a project for?")
@@ -46,7 +54,6 @@ def create_new_project(session):
             project_team.append(user)
 
     dest_folder = None
-
     for child in team["children"]:
         if child["name"] == "Projects":
             dest_folder = child
@@ -63,7 +70,7 @@ def create_new_project(session):
         else:
             print("didnt get ya fully")
             continue
-    
+
     while True:
         projname = input("Enter project letter code (3 characters):")
         if len(projname) == 3:
@@ -108,12 +115,14 @@ def create_new_project(session):
             "name": project_name,
             "parent": dest_folder,
             "description": desc,
+            "thumbnail_id": ams_thumb
         },
     )
 
     task_templates = team["project_schema"]["task_templates"]
 
     for template in task_templates:
+        #print(template["name"])
         if template["name"] == "Annelies_Template":
             annelies_template = template
         if template["name"] == "Image_Template":
@@ -128,31 +137,36 @@ def create_new_project(session):
         task = session.create("Task",
                               {"name": task_type["name"],
                                "type": task_type,
+                               "thumbnail_id": ams_thumb,
                                "parent": proj})
-        session.create(
-            "Appointment",
-            {"context": task,
-             "resource": project_manager,
-             "type": "assignment"},
-        )
+        session.create("Appointment", {
+                       "context": task,
+                       "resource": project_manager,
+                       "type": "assignment"},
+                       )
 
     for u in users:
         if u["username"] == "Annelies.Cardoen":
             annelies = u
 
     for task_type in [t["task_type"] for t in annelies_template["items"]]:
-        task = session.create(
-            "Task", {"name": task_type["name"], "type": task_type, "parent": proj}
-        )
+        task = session.create("Task", {
+                              "name": task_type["name"],
+                              "type": task_type,
+                              "thumbnail_id": ams_thumb,
+                              "parent": proj}
+                              )
         session.create(
             "Appointment", {"context": task, "resource": annelies, "type": "assignment"}
         )
 
     if num_int > 0:
-        int_folder = session.create("Folder",
-                                    {"name": f"{num}_INT", "parent": proj})
+        int_folder = session.create("Folder", {
+                                    "name": f"{num}_INT",
+                                    "parent": proj,
+                                    "thumbnail_id": ams_thumb})
 
-        if len(project_team) > 1:    
+        if len(project_team) > 1:
             ia, index = pick(
                 [u["username"] for u in project_team],
                 "Select interior artist:",
@@ -163,21 +177,29 @@ def create_new_project(session):
 
         for i in range(num_int):
             int_shot_name = f"{num}_INT_{chr(ord('@')+i+1)}"
-            int_shot = session.create(
-                "Image", {"name": int_shot_name, "parent": int_folder}
-            )
+            int_shot = session.create("Image", {
+                                      "name": int_shot_name,
+                                      "parent": int_folder,
+                                      "thumbnail_id": ams_thumb}
+                                      )
             for task_type in [t["task_type"] for t in image_template["items"]]:
-                task = session.create(
-                    "Task",
-                    {"name": task_type["name"], "type": task_type, "parent": int_shot},
-                )
+                task = session.create("Task", {
+                                      "name": task_type["name"],
+                                      "type": task_type,
+                                      "parent": int_shot,
+                                      "thumbnail_id": ams_thumb},
+                                      )
                 session.create(
                     "Appointment",
                     {"context": task, "resource": int_artist, "type": "assignment"},
                 )
 
     if num_ext > 0:
-        ext_folder = session.create("Folder", {"name": f"{num}_EXT", "parent": proj})
+        ext_folder = session.create("Folder", {
+                                    "name": f"{num}_EXT",
+                                    "parent": proj,
+                                    "thumbnail_id": ams_thumb}
+                                    )
 
         if len(project_team) > 1:
 
@@ -190,19 +212,32 @@ def create_new_project(session):
 
         for i in range(num_ext):
             ext_shot_name = f"{num}_EXT_{chr(ord('@')+i+1)}"
-            ext_shot = session.create(
-                "Image", {"name": ext_shot_name, "parent": ext_folder}
-            )
+            ext_shot = session.create("Image", {
+                                      "name": ext_shot_name,
+                                      "parent": ext_folder,
+                                      "thumbnail_id": ams_thumb}
+                                      )
             for task_type in [t["task_type"] for t in image_template["items"]]:
-                task = session.create(
-                    "Task",
-                    {"name": task_type["name"], "type": task_type, "parent": ext_shot},
-                )
+                task = session.create("Task", {
+                                      "name": task_type["name"],
+                                      "type": task_type,
+                                      "parent": ext_shot,
+                                      "thumbnail_id": ams_thumb},
+                                      )
                 session.create(
                     "Appointment",
                     {"context": task, "resource": ext_artist, "type": "assignment"},
                 )
 
+    # using a set here to make sure non users are added multiple times
+    project_set = set()
+    project_set.add(int_artist)
+    project_set.add(ext_artist)
+
+    for artist in project_set:
+        print(artist["username"])
+        pass
+
     drone = get_yes_no("Does the project require photography?")
 
     session.commit()
@@ -211,8 +246,8 @@ def create_new_project(session):
     print(f"--- creating objects for {project_name} on ftrack")
     print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
-    print(f"-- {num_int} INT tasks for {ia}") if num_int > 0 else None
-    print(f"-- {num_ext} EXT tasks for {exterior_artist}") if num_ext > 0 else None
+    print(f"-- {num_int} INT tasks for {int_artist['username']}") if num_int > 0 else None
+    print(f"-- {num_ext} EXT tasks for {ext_artist['username']}") if num_ext > 0 else None
     print("--- creating photography tasks") if drone else None
     print(f"--- creating {project_name}.mxp for 3dsmax project")
     print(f"--- updating {project_name} on teamleader")
